@@ -53,14 +53,12 @@ avgFacLvls <- function(matrix, fac) {
 		 # cat("Loop #", i, "\n")
 		 # cat("  Level is  ", lev[i], "\n")
 		 # cat("  Length of level", i, "is", length(w), "\n")
-		 # cat("w = ", w, "\n")
-		m <- M[w,] #submatrix for a given level
+		 # cat("  w = ", w, "\n")
+		m <- M[w,] # submatrix for a given level
 		avg <- colMeans(m)
 		
-# Create a matrix
-# in which the averages replace the actual spectra
-	
-		M[w,] <- rep(avg, each = length(w))
+		# Replace the spectra with the group averages
+		for (j in 1:length(w)) M[w[j],] <- avg
 		} 
 		return(M)
 	}
