@@ -6,50 +6,25 @@
 #' \code{\link[utils]{read.table}} to read files so they are
 #' very flexible in regard to file formatting.  \pkg{Be sure to see the \ldots
 #' argument below for important details you need to provide.}
-#' 
-#' The matching of \code{gr.crit} against the sample file names is done one at
-#' a time, in order.  This means that the entries in \code{gr.crit} must be
-#' mutually exclusive.  For example, if you have files with names like
-#' "Control_1" and "Sample_1" and use \code{gr.crit = c("Control", "Sample")}
-#' groups will be assigned as you would expect.  But, if you have file names
-#' like "Control_1_Shade" and "Sample_1_Sun" you can't use \code{gr.crit =
-#' c("Control", "Sample", "Sun", "Shade")} because each criteria is grepped in
-#' order, and the "Sun/Shade" phrases, being last, will form the basis for your
-#' groups.  Because this is a grep process, you can get around this by using
-#' regular expressions in your \code{gr.crit} argument to specify the desired
-#' groups in a mutually exclusive manner.  In this second example, you could
-#' use \code{gr.crit = c("Control(.*)Sun", "Control(.*)Shade", "Sample(.*)Sun",
-#' "Sample(.*)Shade")} to have your groups assigned based upon both phrases in
-#' the file names.
-#' 
-#' The linking of groups with colors is handled by \code{\link{groupNcolor}}.
-#' 
-#' Samples whose names are not matched using \code{gr.crit} are still
-#' incorporated into the \code{\link{Spectra}} object, but they are not
-#' assigned a group or color. Therefore they don't plot, but they do take up space in a
-#' plot!  A warning is issued in these cases, since one wouldn't normally want
-#' a spectrum to be orphaned this way.
 #'
-#' If \code{fileExt} contains any of \code{"dx"}, \code{"DX"}, \code{"jdx"} or
-#' \code{"JDX"}, then the files will be processed by \code{\link[readJDX]{readJDX}}.
-#' Consider setting \code{debug = TRUE} for this format, as there are many
-#' options for JCAMP, and many are untested. See \code{\link[readJDX]{readJDX}} for
-#' known limitations.
-#' 
-#' 
 #' @param gr.crit Group Criteria.  A vector of character strings which will be
-#' searched for among the file names in order to assign an individual
-#' spectrum/sample to group membership. Warnings are issued if there are file
+#' searched for among the file/sample names in order to assign an individual
+#' spectrum to group membership. This is done using grep, so characters
+#' like "." (period/dot) do not have their literal meaning (see below).
+#' Warnings are issued if there are file/sample
 #' names that don't match entries in \code{gr.crit} or there are entries in
-#' \code{gr.crit} that don't match any file names. See Details for some
-#' nuances.
+#' \code{gr.crit} that don't match any file names.  A maximum of 8 groups
+#' can automatically be assigned colors and symbols.  If you have more than 8
+#' groups, you will need to provide a vector of colors (see below) and 
+#' manually fix the symbols after the \code{Spectra} object is created.
 #' 
 #' @param gr.cols Group Colors.  Either the word "auto", in which case colors
 #' will be automatically assigned, or a vector of acceptable color names with
 #' the same length as \code{gr.crit}. In the latter case, colors will be
 #' assigned one for one, so the first element of \code{gr.crit} is assigned the
-#' first element of \code{gr.col} and so forth.  See details below for some
-#' other issues to consider.
+#' first element of \code{gr.col} and so forth. A maximum of 8 colors can be
+#' assigned automatically, after that, you must give a vector of colors.
+#' See details below for some other issues to consider.
 #' 
 #' @param freq.unit A character string giving the units of the x-axis
 #' (frequency or wavelength).
@@ -97,11 +72,19 @@
 #' 
 #' @section files2SpectraObject:
 #' \code{files2SpectraObject} acts on all files in the current working
-#' directory with the specified \code{fileExt}.  The first column should
+#' directory with the specified \code{fileExt} so there should be no
+#' extra files of that type hanging around (except see next paragraph).
+#' The first column should
 #' contain the frequency values and the second column the intensity values. The
 #' files may have a header or not (supply \code{header = TRUE/FALSE} as
 #' necessary).  The frequency column is assumed to be the same in all files.
 #' 
+#' If \code{fileExt} contains any of \code{"dx"}, \code{"DX"}, \code{"jdx"} or
+#' \code{"JDX"}, then the files will be processed by \code{\link[readJDX]{readJDX}}.
+#' Consider setting \code{debug = TRUE} for this format, as there are many
+#' options for JCAMP, and many are untested. See \code{\link[readJDX]{readJDX}} for
+#' known limitations.
+#' 
 #' @section matrix2SpectraObject:
 #' This function takes a csv-like file, containing frequencies in the first
 #' column, and samples in additional columns, and processes it into a
@@ -109,10 +92,56 @@
 #' the sample names.  There need not be a header for the first (frequency)
 #' column.
 #'
+#' @section gr.crit and Sample Name Gotchas:
+#'
+#' The matching of \code{gr.crit} against the sample file names
+#' (in \code{files2SpectraObject}) or column headers/sample names
+#' (in code{matrix2SpectraObject}) is done one at
+#' a time, in order, using grep.  While powerful, this has the potential to lead
+#' to some "gotchas" in certain cases, noted below.  
+#'
+#' Your file system may allow file/sample names which \code{R} will not like, and will
+#' cause confusing behavior.  File/sample names become variables in \code{ChemoSpec},
+#' and \code{R}
+#' does not like things like "-" (minus sign or hyphen) in file/sample names.  A hyphen
+#' is converted to a period (".") if found, which is fine for a variable name.
+#' However, a period in \code{gr.crit} is interpreted from the grep point of view,
+#' namely a period matches any single character.  At this point, things may behave
+#' very differently than one might hope.  See \code{\link{make.names}} for allowed
+#' characters in \code{R} variables and make sure your file/sample names comply.
+#'
+#' The entries in \code{gr.crit} must be
+#' mutually exclusive.  For example, if you have files with names like
+#' "Control_1" and "Sample_1" and use \code{gr.crit = c("Control", "Sample")}
+#' groups will be assigned as you would expect.  But, if you have file names
+#' like "Control_1_Shade" and "Sample_1_Sun" you can't use \code{gr.crit =
+#' c("Control", "Sample", "Sun", "Shade")} because each criteria is grepped in
+#' order, and the "Sun/Shade" phrases, being last, will form the basis for your
+#' groups.  Because this is a grep process, you can get around this by using
+#' regular expressions in your \code{gr.crit} argument to specify the desired
+#' groups in a mutually exclusive manner.  In this second example, you could
+#' use \code{gr.crit = c("Control(.*)Sun", "Control(.*)Shade", "Sample(.*)Sun",
+#' "Sample(.*)Shade")} to have your groups assigned based upon both phrases in
+#' the file names.
+#'
+#' To summarize, \code{gr.crit} is used as a grep pattern, and the file/sample names
+#' are the target.  Make sure your file/sample names comply with \code{\link{make.names}}.
+#'
+#' Finally, samples whose names are not matched using \code{gr.crit} are still
+#' incorporated into the \code{\link{Spectra}} object, but they are not
+#' assigned a group or color. Therefore they don't plot, but they do take up space in a
+#' plot!  A warning is issued in these cases, since one wouldn't normally want
+#' a spectrum to be orphaned this way.
+#'
+#' All these problems can generally be identified by running \code{\link{sumSpectra}}
+#' once the data is imported.
+#'
 #' @author Bryan A. Hanson, DePauw University.
 #' 
 #' @references \url{https://github.com/bryanhanson/ChemoSpec}
 #' 
+#' @seealso The linking of groups with colors is handled by \code{\link{groupNcolor}}.
+#' 
 #' @keywords file
 #' @keywords import
 #' 
@@ -146,6 +175,8 @@ files2SpectraObject <- function(gr.crit = NULL,
 	fileExt = "\\.(csv|CSV)$",
 	out.file = "mydata", debug = FALSE, ...) {
 		
+	out <- tryCatch(
+	{
 # Function to Read & Prep Spectroscopic Data
 # from raw data files into an Spectra object
 # Part of the ChemoSpec package
@@ -161,8 +192,6 @@ files2SpectraObject <- function(gr.crit = NULL,
 	if (!requireNamespace("R.utils", quietly = TRUE)) {
 		stop("You need to install package R.utils to use this function")
 		}
-
-	message("The default behavior of this function has changed as of July 2016.\nSee ?files2SpectraObject.  Really: please read it!")
 	
 	if (is.null(gr.crit)) stop("No group criteria provided to encode data")
 	
@@ -177,14 +206,14 @@ files2SpectraObject <- function(gr.crit = NULL,
 	# First set up some common stuff
 	
 	files <- list.files(pattern = fileExt)
-	files.noext <- file_path_sans_ext(files)
+	files.noext <- tools::file_path_sans_ext(files)
 
 	spectra <- list()
 	spectra$names <- files.noext
 
 	if (debug) message("\nfiles2SpectraObject is checking the first file")
 	if (!DX) {
-		temp <- read.table(files[1], ...)
+		temp <- utils::read.table(files[1], ...)
 		spectra$freq <- temp[,1]
 		}
 	if (DX) {
@@ -207,7 +236,7 @@ files2SpectraObject <- function(gr.crit = NULL,
 	for (i in 1:length(files)) {
 		if (debug) cat("Importing file: ", files[i], "\n")
 		if (!DX) {
-			temp <- read.table(files[i], ...)
+			temp <- utils::read.table(files[i], ...)
 			spectra$data[i,] <- temp[,2]
 			}
 		if (DX) {
@@ -229,5 +258,17 @@ files2SpectraObject <- function(gr.crit = NULL,
 	R.utils::saveObject(spectra, file = datafile)
 	
 	return(spectra)
+	},
+	
+	error = function(cond) {
+		errmess <- "There was a problem importing your files!\n\nAre you importing csv or similar files?\nDid you get a message such as 'undefined columns selected'?\nYou probably need to specify sep, header and dec values\nPlease read ?files2SpectraObject for details\n\nFor any trouble importing files set debug = TRUE\n"
+		message("\nError message from R: ", cond$message, "\n")
+		message(errmess)
+		return(NA)
+		}
+	
+	) # end of tryCatch
+	
+	return(out)
 	}
 
