@@ -1,7 +1,5 @@
 ## ----SetUp, echo = FALSE, eval = TRUE, results = "hide"----
 
-# You must knit this file with getwd() set to the directory it is in!
-
 # R options & configuration:
 
 rm(list = ls())
@@ -9,22 +7,11 @@ options(width =  50, show.signif.stars = FALSE)
 
 suppressMessages(library("knitr"))
 suppressMessages(library("ChemoSpec"))
-
 suppressMessages(library("RColorBrewer"))
 suppressMessages(library("mvbutils"))
 suppressMessages(library("sna"))
 suppressMessages(library("mclust"))
 
-
-#suppressMessages(library("IDPmisc"))
-#suppressMessages(library("stats"))
-#suppressMessages(library("utils"))
-#suppressMessages(library("grDevices"))
-
-# Other packages in Suggests but apparently not needed:
-# DPmisc, amap, seriation, speaq, clusterCrit, NbClust, R.utils, baseline,  gsubfn, lattice, pcaPP, pls, grid, robustbase, MASS
-
-
 desc <- packageDescription("ChemoSpec")
 vers <- paste("(Package Version ", desc$Version, ")", sep = "")
 #vers <- paste("R package version", meta$Version)
@@ -39,7 +26,7 @@ opts_chunk$set(out.width = "0.8\\textwidth", fig.align = "center", fig.width = 7
 #  source("My_First_ChemoSpec.R")
 
 ## ----Chunk2,  results = "hide", eval = FALSE----
-#  files2SpectraObject(gr.crit = c("sspA", "sspB"), gr.cols = c("red3", "dodgerblue4"),
+#  ssp <- files2SpectraObject(gr.crit = c("sspA", "sspB"), gr.cols = c("red", "blue"),
 #  freq.unit = "ppm", int.unit = "peak intensity", descrip = "Subspecies Study",
 #  out.file = "subspecies")
 
@@ -54,21 +41,18 @@ sumSpectra(SrE.IR)
 # We'll make a fancy title here and re-use in other plots
 myt <- expression(bolditalic(Serenoa)~bolditalic(repens)~bold(Extract~IR~Spectra))
 plotSpectra(SrE.IR, main = myt,
-which = c(1, 2, 14, 16),
-yrange = c(0, 1.6), offset = 0.4, lab.pos = 2200)
+  which = c(1, 2, 14, 16),
+  yrange = c(0, 1.6), offset = 0.4, lab.pos = 2200)
 
 ## ----Chunk10, fig.cap = "\\label{subplot}Zooming in on a Spectral Region"----
 plotSpectra(SrE.IR, main = myt,
-which = c(1, 2, 14, 16), xlim = c(1650, 1800),
-yrange = c(0, 0.6), offset = 0.1, lab.pos = 1775)
+  which = c(1, 2, 14, 16), xlim = c(1650, 1800),
+  yrange = c(0, 0.6), offset = 0.1, lab.pos = 1775)
 
 ## ----Chunk9-------------------------------------
 SrE.IR$names # suitable if there are not many spectra
 grep("OO", SrE.IR$names) # use if there are more spectra
 
-## ----Chunk17, eval = FALSE, echo = TRUE---------
-#  not_wanted <- normSpectra(SrE.IR)
-
 ## ----Chunk18------------------------------------
 tmp <- binSpectra(SrE.IR, bin.ratio = 4)
 sumSpectra(tmp)
@@ -84,7 +68,7 @@ grep("TD_adSrE", noTD$names)
 ## ----Chunk12------------------------------------
 SrE <- grep("SrE", SrE2.IR$names)
 SrE2.IR$names[SrE] # gives the name(s) that contain "SrE"
-SrE # gives the corresponding indicies
+SrE # gives the corresponding indices
 
 ## ----Chunk14,  fig.width = 8, fig.height = 5, fig.cap = "\\label{surv}Checking for Regions of No Interest"----
 surveySpectra(SrE2.IR, method = "iqr", main = myt, by.gr = FALSE)
@@ -94,21 +78,21 @@ surveySpectra2(SrE2.IR, method = "iqr", main = myt)
 
 ## ----Chunk14a, fig.cap = "\\label{survA}Detail of Carbonyl Region"----
 surveySpectra(SrE2.IR, method = "iqr", main = "S. repens Detail of Carbonyl Region",
-by.gr = FALSE, xlim = c(1650, 1800))
+  by.gr = FALSE, xlim = c(1650, 1800))
 
 ## ----Chunk14b, fig.cap = "\\label{survB}Detail of Carbonyl Region by Group"----
 surveySpectra(SrE2.IR, method = "iqr", main = "S. repens Detail of Carbonyl Region",
-by.gr = TRUE, xlim = c(1650, 1800))
+  by.gr = TRUE, xlim = c(1650, 1800))
 
 ## ----Chunk14c, fig.cap = "\\label{survC}Inspection of an Uninteresting Spectral Region"----
 surveySpectra(SrE2.IR, method = "iqr", main = "S. repens Detail of Empty Region",
-by.gr = FALSE, xlim = c(1800, 2500), ylim = c(0.0, 0.05))
+  by.gr = FALSE, xlim = c(1800, 2500), ylim = c(0.0, 0.05))
 
 ## ----Chunk15------------------------------------
 SrE3.IR <- removeFreq(SrE2.IR, rem.freq = SrE2.IR$freq > 1800 & SrE2.IR$freq < 2500)
 sumSpectra(SrE3.IR)
 
-## ----Chunk7, fig.cap = "\\label{gaps}Procedure to Find Gaps in a Data Set" , tidy = FALSE----
+## ----Chunk7, fig.cap = "\\label{gaps}Identifying Gaps in a Data Set" , tidy = FALSE----
 check4Gaps(SrE3.IR$freq, SrE3.IR$data[1,], plot = TRUE)
 
 ## ----Chunk19, fig.cap = "\\label{hca}Hierarchical Cluster Analysis"----
@@ -117,12 +101,12 @@ HCA <- hcaSpectra(SrE3.IR, main = myt)
 ## ----Chunk10a, fig.cap = "\\label{classPCA}Classical PCA"----
 class <- c_pcaSpectra(SrE3.IR, choice = "noscale")
 plotScores(SrE3.IR, main = myt, class,
-pcs = c(1,2), ellipse = "rob", tol = 0.01)
+  pcs = c(1,2), ellipse = "rob", tol = 0.01)
 
 ## ----Chunk21, fig.cap = "\\label{robPCA}Robust PCA"----
 robust <- r_pcaSpectra(SrE3.IR, choice = "noscale")
 plotScores(SrE3.IR, main = myt, robust,
-pcs = c(1,2), ellipse = "rob", tol = 0.01)
+  pcs = c(1,2), ellipse = "rob", tol = 0.01)
 
 ## ----Chunk22, fig.cap = "\\label{OD}Diagnostics: Orthogonal Distances"----
 diagnostics <- pcaDiag(SrE3.IR, class, pcs = 2, plot = "OD")
@@ -141,39 +125,36 @@ out <- cv_pcaSpectra(SrE3.IR, pcs = 5, choice = "noscale")
 
 ## ----Chunk26,  results = "hide", eval = FALSE----
 #  plotScoresRGL(SrE3.IR, class, main = "S. repens IR Spectra",
-#  leg.pos = "A", t.pos = "B") # not run - it's interactive!
+#    leg.pos = "A", t.pos = "B") # not run - it's interactive!
 
 ## ----Chunk27, fig.cap = "\\label{s3D}Plotting Scores in 3D using plotScores3D"----
 plotScores3D(SrE3.IR, class, main = myt, ellipse = FALSE)
 
 ## ----Chunk29, fig.cap = "\\label{load}Loading Plot"----
-plotLoadings(SrE3.IR, class, main = myt,
-loads = c(1, 2), ref = 1)
+plotLoadings(SrE3.IR, class, main = myt, loads = c(1, 2), ref = 1)
 
 ## ----Chunk30, fig.cap = "\\label{load2}Plotting One Loading vs. Another"----
-res <- plot2Loadings(SrE3.IR, class, main = myt,
-loads = c(1, 2), tol = 0.002)
+res <- plot2Loadings(SrE3.IR, class, main = myt, loads = c(1, 2), tol = 0.002)
 
 ## ----Chunk30a,  fig.cap = "\\label{splot}s-Plot to Identify Influential Frequencies"----
 spt <- sPlotSpectra(SrE3.IR, class, main = myt, pc = 1, tol = 0.001)
 
 ## ----Chunk30b,  fig.cap = "\\label{splot2}s-Plot Detail"----
-spt <- sPlotSpectra(SrE3.IR, class, main = "Detail of S. repens IR Spectra", pc = 1, tol = 0.05, xlim = c(-0.04, -0.01), ylim = c(-1.05, -0.9))
+spt <- sPlotSpectra(SrE3.IR, class, main = "Detail of S. repens IR Spectra", pc = 1,
+  tol = 0.05, xlim = c(-0.04, -0.01), ylim = c(-1.05, -0.9))
 
 ## ----Chunk31,  results = "hide", eval = FALSE----
 #  hcaScores(SrE3.IR,  class, scores = c(1:5), main = myt)
 
 ## ----Chunk35, fig.cap = "\\label{mclust1}mclust Chooses an Optimal Model"----
-model <- mclustSpectra(SrE3.IR, class, plot = "BIC",
-main = myt)
+model <- mclustSpectra(SrE3.IR, class, plot = "BIC", main = myt)
 
 ## ----Chunk36, fig.cap = "\\label{mclust2}mclust's Thoughts on the Matter"----
-model <- mclustSpectra(SrE3.IR, class, plot = "proj",
-main = myt)
+model <- mclustSpectra(SrE3.IR, class, plot = "proj", main = myt)
 
 ## ----Chunk37, fig.cap = "\\label{mclust3}Comparing mclust Results to the TRUTH"----
 model <- mclustSpectra(SrE3.IR, class, plot = "errors",
-main = myt, truth = SrE3.IR$groups)
+  main = myt, truth = SrE3.IR$groups)
 
 ## ----Chunk33,  results = "hide", eval = FALSE----
 #  mclust3dSpectra(SrE3.IR, class) # not run - it's interactive!
